;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "erlang" "29.0.5"
  "Major modes for editing and running Erlang."
  '((emacs "27.1"))
  :url "https://github.com/erlang/otp"
  :commit "5cf5f9725452f4e1b6a4890e8ff0305d76924b98"
  :revdesc "OTP-29.0.5-0-g5cf5f9725452"
  :keywords '("erlang" "languages" "processes"))
